/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2018 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy18nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy18nid ;

DATA library.&dataset ;
INFILE datafile LRECL=465;
INPUT
   USSCIDN  1-7             STMIN851  8-11           STMAX851  12-15       
   FILED  16                WITHDRWN  17             RELIEF  18            
   CTRELIEF  19             CRMHT851  20             INDTDATE DATE11.      
   FILEDATE DATE11.         PROFFN1  43-45           PROFFN2  46-48        
   PROFFN3  49-51           PROFFN4  52-54           PROFFN5  55-57        
   PROFFN6  58-60           PROFFN7  61-63           PROFFN8  64-66        
   PROFFN9  67-69           PROFFN10  70-72          PROFFN11  73-75       
   PROFFN12  76-78          PROFFN13  79-81          PROFFN14  82-84       
   PROFFN15  85-87          PROFFN16  88-90          PROFFN17  91-93       
   PROFFN18  94-96          PROFFN19  97-99          PROFFN20  100-102     
   PROFFN21  103-105        PROFFN22  106-108        PRSENT1  109-112      
   PRSENT2  113-116         PRSENT3  117-120         PRSENT4  121-124      
   PRSENT5  125-128         PRSENT6  129-132         PRSENT7  133-136      
   PRSENT8  137-140         PRSENT9  141-144         PRSENT10  145-148     
   PRSENT11  149-152        PRSENT12  153-156        PRSENT13  157-160     
   PRSENT14  161-163        PRSENT15  164-167        PRSENT16  168-171     
   PRSENT17  172            PRSENT18  173            PRSENT19  174         
   PRSENT20  175            PRSENT21  176            PRSENT22  177         
   PRSNDT1 DATE11.          PRSNDT2 DATE11.          PRSNDT3 DATE11.       
   PRSNDT4 DATE11.          PRSNDT5 DATE11.          PRSNDT6 DATE11.       
   PRSNDT7 DATE11.          PRSNDT8 DATE11.          PRSNDT9 DATE11.       
   PRSNDT10 DATE11.         PRSNDT11 DATE11.         PRSNDT12 DATE11.      
   PRSNDT13 DATE11.         PRSNDT14 DATE11.         PRSNDT15 DATE11.      
   PRSNDT16 DATE11.         PRSNDT17 DATE11.         PRSNDT18 DATE11.      
   PRSNDT19 DATE11.         PRSNDT20 DATE11.         PRSNDT21 DATE11.      
   PRSNDT22 DATE11.         OFFENNUM  420-421        PRCHPT1  422          
   PRCHPT2  423             PRCHPT3  424             PRCHPT4  425          
   PRCHPT5  426             PRCHPT6  427             PRCHPT7  428          
   PRCHPT8  429             PRCHPT9  430             PRCHPT10  431         
   PRCHPT11  432            PRCHPT12  433            PRCHPT13  434         
   PRCHPT14  435            PRCHPT15  436            PRCHPT16  437         
   PRCHPT17  438            PRCHPT18  439            PRCHPT19  440         
   PRCHPT20  441            PRCHPT21  442            PRCHPT22  443         
   PRFELN1  444             PRFELN2  445             PRFELN3  446          
   PRFELN4  447             PRFELN5  448             PRFELN6  449          
   PRFELN7  450             PRFELN8  451             PRFELN9  452          
   PRFELN10  453            PRFELN11  454            PRFELN12  455         
   PRFELN13  456            PRFELN14  457            PRFELN15  458         
   PRFELN16  459            PRFELN17  460            PRFELN18  461         
   PRFELN19  462            PRFELN20  463            PRFELN21  464         
   PRFELN22  465          ;                       

FORMAT
   INDTDATE DATE9.          FILEDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.          PRSNDT15 DATE9.          PRSNDT16 DATE9.       
   PRSNDT17 DATE9.          PRSNDT18 DATE9.          PRSNDT19 DATE9.       
   PRSNDT20 DATE9.          PRSNDT21 DATE9.          PRSNDT22 DATE9.       
 ;
                      

LENGTH
   USSCIDN 6                STMIN851 4               STMAX851 4            
   FILED 3                  WITHDRWN 3               RELIEF 3              
   CTRELIEF 3               CRMHT851 3               PROFFN1 4             
   PROFFN2 4                PROFFN3 4                PROFFN4 4             
   PROFFN5 4                PROFFN6 4                PROFFN7 4             
   PROFFN8 4                PROFFN9 4                PROFFN10 4            
   PROFFN11 4               PROFFN12 4               PROFFN13 4            
   PROFFN14 4               PROFFN15 4               PROFFN16 4            
   PROFFN17 4               PROFFN18 4               PROFFN19 4            
   PROFFN20 4               PROFFN21 4               PROFFN22 4            
   PRSENT1 4                PRSENT2 4                PRSENT3 4             
   PRSENT4 4                PRSENT5 4                PRSENT6 4             
   PRSENT7 4                PRSENT8 4                PRSENT9 4             
   PRSENT10 4               PRSENT11 4               PRSENT12 4            
   PRSENT13 4               PRSENT14 4               PRSENT15 4            
   PRSENT16 4               PRSENT17 3               PRSENT18 3            
   PRSENT19 3               PRSENT20 3               PRSENT21 3            
   PRSENT22 3               OFFENNUM 3               PRCHPT1 3             
   PRCHPT2 3                PRCHPT3 3                PRCHPT4 3             
   PRCHPT5 3                PRCHPT6 3                PRCHPT7 3             
   PRCHPT8 3                PRCHPT9 3                PRCHPT10 3            
   PRCHPT11 3               PRCHPT12 3               PRCHPT13 3            
   PRCHPT14 3               PRCHPT15 3               PRCHPT16 3            
   PRCHPT17 3               PRCHPT18 3               PRCHPT19 3            
   PRCHPT20 3               PRCHPT21 3               PRCHPT22 3            
   PRFELN1 3                PRFELN2 3                PRFELN3 3             
   PRFELN4 3                PRFELN5 3                PRFELN6 3             
   PRFELN7 3                PRFELN8 3                PRFELN9 3             
   PRFELN10 3               PRFELN11 3               PRFELN12 3            
   PRFELN13 3               PRFELN14 3               PRFELN15 3            
   PRFELN16 3               PRFELN17 3               PRFELN18 3            
   PRFELN19 3               PRFELN20 3               PRFELN21 3            
   PRFELN22 3 ;

        

RUN ;
